@@ -379,16 +379,6 @@ function main() {
     // make sure settings file path is reinitialized:
     RSettings.uninit();
 
-    // alternative path for QCAD3.ini:
-    for (i=1; i<args.length; ++i) {
-        if (args[i] === "-config") {
-            ++i;
-            if (i < args.length) {
-                QSettings.setPath(QSettings.IniFormat, QSettings.UserScope, getAbsolutePathForArg(args[i]));
-            }
-        }
-    }
-
     // ignore config file if it does not identify itself with a version
     // number or is known as being incompatible
     var reset = false;
@@ -445,11 +435,17 @@ function main() {
     var pluginInfo;
 
     // look up app name override:
+    var maxPri = 0;
     for (i=0; i<numPlugins; i++) {
         pluginInfo = RPluginLoader.getPluginInfo(i);
-        var n = pluginInfo.get("NameOverride", "");
-        if (n.length>0) {
-            qApp.applicationName = n;
+        var np = pluginInfo.get("OverridePriority", "0");
+        np = parseInt(np);
+        if (parseInt(np)>maxPri) {
+            maxPri = np;
+            var n = pluginInfo.get("NameOverride", "");
+            if (n.length>0) {
+                qApp.applicationName = n;
+            }
         }
     }
 
@@ -486,7 +482,7 @@ function main() {
 
     // splash:
     var splash = undefined;
-    if (RSettings.getBoolValue("Startup/EnableSplashScreen", true)) {
+    if (RSettings.getBoolValue("Startup/EnableSplashScreen", true) && !args.contains("-no-show")) {
         var fn;
         var key;
         if (RSettings.getDevicePixelRatio()===2) {
@@ -525,9 +521,7 @@ function main() {
         var pixmap = new QPixmap(fn);
         splash = new QSplashScreen(pixmap);
         splash.objectName = "Splash";
-        if (!args.contains("-no-show")) {
-            splash.show();
-        }
+        splash.show();
     }
 
     RFontList.initSubstitutions();
@@ -650,7 +644,7 @@ function main() {
 
     if (!isNull(splash)) {
         splash.close();
-        destr(splash);
+        destrDialog(splash);
     }
 
     postInitAddOns(addOns);
@@ -689,13 +683,15 @@ function main() {
     // open files given on command line:
     var clickedFilesAndArgs = filesToOpen.concat(args.slice(1));
     QCoreApplication.processEvents();
-    appWin.setProperty("starting", true);
+    appWin.setProperty("__starting__", true);
     var restored = false;
     if (typeof(restoreFiles)=="function") {
+        appWin.setProperty("__restoring__", true);
         restored = restoreFiles();
+        appWin.setProperty("__restoring__", false);
     }
     openFiles(clickedFilesAndArgs, !recovered && !restored);
-    appWin.setProperty("starting", false);
+    appWin.setProperty("__starting__", false);
 
     RPluginLoader.postInitPlugins(RPluginInterface.LoadedFiles);
 
@@ -717,7 +713,24 @@ function main() {
         w.setFocus();
     }
 
-    if (!RSettings.hasQuitFlag()) {
+    if (RSettings.getQtVersion()<0x060000) {
+        if (!RSettings.hasQuitFlag()) {
+            // start and enter the main application loop:
+            QCoreApplication.exec();
+        }
+    }
+    else {
+        // Qt 6: always enter main application loop but quit immediately from the loop
+        // if -quit flag is given
+        if (RSettings.hasQuitFlag()) {
+            var singleShot = new QTimer(qApp);
+            singleShot.singleShot = true;
+            singleShot.timeout.connect(function() {
+                QCoreApplication.quit();
+            });
+            singleShot.start(100);
+        }
+
         // start and enter the main application loop:
         QCoreApplication.exec();
     }
@@ -727,7 +740,10 @@ function main() {
     // don't use RSettings below this point
 
     // and we're done:
-    destr(appWin);
+    if (RSettings.getQtVersion()<0x060900) {
+        // Crashes Qt 6.9:
+        destr(appWin);
+    }
     qDebug("done");
 }
 
